@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
  * 
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -30,8 +30,8 @@
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
-#include <jdm.h>
+#include <xfs/libxfs.h>
+#include <xfs/jdm.h>
 
 #include <time.h>
 #include <fcntl.h>
@@ -42,6 +42,7 @@
 #include <sys/mman.h>
 
 #include "types.h"
+#include "util.h"
 #include "mlog.h"
 #include "inv_priv.h"
 #include "arch_xlate.h"
@@ -131,7 +132,7 @@ stobj_insert_session( invt_idxinfo_t *idx,
 
 /* ARGSUSED */
 u_int
-stobj_find_splitpoint( int fd, invt_seshdr_t *harr, u_int ns, time_t tm )
+stobj_find_splitpoint( int fd, invt_seshdr_t *harr, u_int ns, time32_t tm )
 {
 	u_int i;
 
@@ -149,8 +150,8 @@ stobj_find_splitpoint( int fd, invt_seshdr_t *harr, u_int ns, time_t tm )
 	   really possible, but either way, we split at the last entry.
 	   This will impact the guarantee that invindex tries to give - that
 	   there's always a unique stobj for every session. */
-	mlog( MLOG_VERBOSE | MLOG_INV,
-	      "INV: failed to find a different sh_time to split\n"
+	mlog( MLOG_VERBOSE | MLOG_INV, _(
+	      "INV: failed to find a different sh_time to split\n")
 	     );
 	      
 	return ns - 1;
@@ -971,7 +972,9 @@ stobj_delete_mobj(int fd,
 		for ( j = 0; j < nmfiles; j++ ) {
 			mf = &mfiles[j];
 			if ( !uuid_compare( mf->mf_moid, *moid ) ) {
+#ifdef INVT_DEBUG
 				printf(" found one\n" );
+#endif
 
 /*                                dirty = BOOL_TRUE;	
 
@@ -1023,7 +1026,8 @@ stobj_unpack_sessinfo(
 	/* first make sure that the magic cookie at the beginning is right.
 	   this isn't null-terminated */
 	if (strncmp( p, INVTSESS_COOKIE, strlen( INVTSESS_COOKIE ) ) != 0) {
-		mlog( MLOG_NORMAL | MLOG_INV,"INV: inv_put_session: unknown cookie\n");
+		mlog( MLOG_NORMAL | MLOG_INV, _(
+			"INV: inv_put_session: unknown cookie\n") );
 		return BOOL_FALSE;
 	}
 	/* skip the cookie */
@@ -1062,8 +1066,9 @@ stobj_unpack_sessinfo(
 		/* At this point , don't care about the INV_VERSION. Maybe in future */
 		p += sizeof( inv_version_t ); /* skip the inventory version */
 	} else {
-	        mlog( MLOG_NORMAL | MLOG_INV,"INV: inv_put_session: unknown packed inventory version"
-		      " %d\n", *( inv_version_t *) p);
+	        mlog( MLOG_NORMAL | MLOG_INV, _(
+		      "INV: inv_put_session: unknown packed inventory version"
+		      " %d\n"), *( inv_version_t *) p);
 		return BOOL_FALSE;
 	} 
 
@@ -1263,9 +1268,16 @@ stobj_copy_invsess(int fd,
 			}
 
 			/* copy the mediafile into the exported structure */
-			stobj_convert_mfile( &ises->s_streams[i].st_mediafiles[j],
-					     &mf);
-			
+			if (ises->s_streams[i].st_mediafiles) {
+				stobj_convert_mfile( &ises->s_streams[i].st_mediafiles[j],
+						&mf);
+			} else {
+				mlog(MLOG_ERROR, _(
+					"Failed to get data from media file: "
+					"possible file corruption\n") );
+				mlog_exit_hint(RV_CORRUPT);
+				return -1;
+			}
 		}
 		
 	}
@@ -1429,7 +1441,7 @@ DEBUG_sessionprint( inv_session_t *ses, u_int ref, invt_pr_ctx_t *prctx)
 	printf("\tsession %d:\n", ref);
 	printf("\t\tmount point:\t%s\n", ses->s_mountpt);
 	printf("\t\tdevice:\t\t%s\n", ses->s_devpath);
-	printf("\t\ttime:\t\t%s", ctime( &ses->s_time ));
+	printf("\t\ttime:\t\t%s", ctime32( &ses->s_time ));
 	printf("\t\tsession label:\t\"%s\"\n", ses->s_label);
 	uuid_unparse( ses->s_sesid, str );
 	printf("\t\tsession id:\t%s\n", str);
